import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class CustomBottomSheet extends StatelessWidget {
  final String title;
  final List<String> options;
  final Widget Function(String option) itemBuilder;
  final Function(int onSelected) onSelected;
  CustomBottomSheet({
    Key key,
    @required this.title,
    @required this.options,
    @required this.onSelected,
    this.itemBuilder,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.only(top: 8),
      decoration: BoxDecoration(
          color: Colors.white,
          borderRadius: BorderRadius.only(
              topLeft: Radius.circular(18), topRight: Radius.circular(18))),
      child: ListView.separated(
        itemBuilder: (context, index) {
          if (index == 0) {
            return buildHeader("$title");
          }
          int newIndex = index - 1;
          if (itemBuilder != null) {
            return GestureDetector(
                onTap: () {
                  onSelected(index);
                },
                child: itemBuilder((options ?? [])[newIndex]));
          }
          return buildOption(newIndex, (options ?? [])[newIndex], (index) {
            onSelected(index);
          });
        },
        separatorBuilder: (context, index) => Divider(
          color: Color(0xffE1E1E1),
        ),
        itemCount: (options ?? []).length + 1,
        shrinkWrap: true,
        physics: ClampingScrollPhysics(),
      ),
    );
  }

  Widget buildOption(int index, String title, Function(int index) onTap) {
    return Builder(
      builder: (context) {
        return CupertinoButton(
          minSize: 0,
          padding: EdgeInsets.all(0),
          onPressed: () => onTap(index),
          child: Container(
            padding: EdgeInsets.symmetric(vertical: 12, horizontal: 18),
            alignment: Alignment.centerLeft,
            child: Text(
              "$title",
              style: TextStyle(color: Color(0xff3B464D), fontSize: 18),
            ),
          ),
        );
      },
    );
  }

  Widget buildHeader(String title) {
    return Builder(
        builder: (context) => Container(
              padding: EdgeInsets.all(12),
              child: Text(
                "$title",
                style: TextStyle(
                    color: Color(0xff3B464D),
                    fontWeight: FontWeight.w700,
                    fontSize: 18),
                textAlign: TextAlign.center,
              ),
            ));
  }
}
